splines/b
B-splines
B-splines (short for basis splines) are useful most for the continuity of their derivatives, making them an excellent choice for camera and object movement where smoothness across knots is paramount but exact position is less important.
Types
Values
pub fn new_2d(
p0: vec2.Vec2(Float),
p1: vec2.Vec2(Float),
p2: vec2.Vec2(Float),
p3: vec2.Vec2(Float),
) -> BSpline(vec2.Vec2(Float))
Constructs a 2d B-spline, given the four control-points as Vec2fs.